Tests
=====

papermill.tests
---------------

This reference documents the tests used in the development of papermill.

papermill.tests.test\_api module
--------------------------------

.. automodule:: papermill.tests.test_api
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_cli module
--------------------------------

.. automodule:: papermill.tests.test_cli
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_conf module
---------------------------------

.. automodule:: papermill.tests.test_conf
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_exceptions module
---------------------------------------

.. automodule:: papermill.tests.test_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_execute module
------------------------------------

.. automodule:: papermill.tests.test_execute
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_iorw module
---------------------------------

.. automodule:: papermill.tests.test_iorw
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_parameterize module
-----------------------------------------

.. automodule:: papermill.tests.test_parameterize
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_s3 module
-------------------------------

.. automodule:: papermill.tests.test_s3
    :members:
    :undoc-members:
    :show-inheritance:

papermill.tests.test\_translators module
----------------------------------------

.. automodule:: papermill.tests.test_translators
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: papermill.tests
    :members:
    :undoc-members:
    :show-inheritance:
